#
# read db: ca_uim table: nas_alarms that contains all "open" alarms
# create HTML report with all current alarms
# 
# input parameters:
# -d: output directory
# -f: output file
#
# sql parameters:
# -u: sql user
# -p: sql password
# -r: sql server
#
# Search Criteria: (regex)
# -mi: message text include
# -me: message text exclude
# -hi: hostname include
# -he: hostname exclude
# -ti: roboT include
# -te: roboT exclude
# -oi: prObe include
# -oe: prObe exclude
#
#
# output:
# - HTML report in directory -d and file -f (by default: c:\temp\report_nimsoft_open_alarms.html)
#
# Example: (only when not running locally or not the standard default directory)
#    perl nimsoft_en_alarms.pl 
#
# Modified:
# 13/04/14: added -i option so that you can define database.db path if using non standard directories
# 08/10/14: add regex filters
#         : exit with rc = selected messages
# 24/10/14: changes switch names to be more logical
#         : add host exclude (-he), robot exclude (-te) and probe exclude (-oe)
# 23/11/15: copied the sqllite version to access the same info in mssql
# 07/12/15: nimsoft_generic.dat will only use passwords that are crypted via nimsoft_crypt.pl
# 20/01/16: sql_type in nimsoft_generic
#

# --- Import external modules
use DBI;
use Getopt::Long;
use DBD::ODBC;
use PerlIO;
# crypt
use Crypt::RC4;
use MIME::Base64;
# UIM generic package
use nimsoft_generic;
# - change directory to directory where perl source is located to find our nimsoft_generic.dat file
use Cwd 'chdir';
use File::Basename;
chdir dirname $0;

# --- variables ---
$SERVER=$ENV{"computername"};
@hostnsplit=split(/\\/, $SERVER);
$hostnn=$#hostnsplit;
$hostn = $hostnsplit[$hostnn];
$colspan=8;
$debug="n";
$pgmname="nimsoft_open_alarms";
# - crypt key
$crkey       = "ab_def%hij&5";
$pgm="Nimsoft_Open_Alarms (v1.1)";

# --- get parameters
&getparams();

# --- loop to create report (not yet implemented)
if ($reportloop eq 'Y')
 {
loop:
  print "Start alarm loop with $reportseconds sleep period\n";
  &base_loop;
  sleep($reportseconds);
  goto loop;
 }
else
 { 
  &base_loop;
 }
print "\n";
exit 0;

# --- procedures

sub base_loop
{
# --- reinit loop variables
$printcount=1;
$sqlcount=0;
$teller=0;
$tel=0;
$totcol=0;
$msg_selected=0;
$msg_excluded=0;
$msg_read=0;

# --- prepare date
&calcdate;

# --- connect DB ---
if ($sqltype eq 'my')
  {
    $dbh = DBI->connect("DBI:mysql:database=$database;host=$sqlserver", "$sqluser", "$sqlpass") || die "Could not connect to nimsoftslm database on $sqlserver: $DBI::errstr";
  }
if ($sqltype eq 'ms')
  {
    if ($trusted eq 'yes')
      {
        $dbh = DBI->connect("DBI:ODBC:Driver={SQL Server};Server=$sqlserver;Database=$database;Trusted_Connection=Yes;") or die("\n\nCONNECT ERROR:\n\n$DBI::errstr");
      }
    else
      {
        $dbh = DBI->connect("DBI:ODBC:Driver={SQL Server};Server=$sqlserver;Database=$database;UID=$sqluser;PWD=$sqlpass") or die("\n\nCONNECT ERROR:\n\n$DBI::errstr");
      } 
  }

# --- open HTML 
open(OUTFILE1, ">$outfil.html") || die("Cannot open file $outfil : $!");

# --- prepare HTML 
&report_header1;
&report_header2;

# --- sql query
$sql = "select time_origin, time_arrival, level, severity, message, suppcount, subsys, source, hostname, prid, robot, hub, nas, domain from nas_alarms order by time_arrival";
$sth = $dbh->prepare($sql);
$sth->execute or die "SQL Error: $DBI::errstr\n";

# --- loop in result of query
while (@row = $sth->fetchrow_array) 
 {
# - decode line
  ($a_time_origin, $a_time_arrival, $a_level, $a_severity, $a_message, $a_suppcount, $a_subsys, $a_source, $a_hostname, $a_prid, $a_robot, $a_hub, $a_nas, $a_domain) = @row;

# --- reset match switch
  $domatch=0;

# --- count msg
  $sqlcount++;

# --- add input regex filters
     if ($s_message_exc ne '' && $a_message =~ /$s_message_exc/i)
      {
        $msg_excluded++;
        goto bypass;
      }
     if ($s_hostname_exc ne '' && $a_hostname =~ /$s_hostname_exc/i)
      {
        $msg_excluded++;
        goto bypass;
      }
     if ($s_robot_exc ne '' && $a_robot =~ /$s_robot_exc/i)
      {
        $msg_excluded++;
        goto bypass;
      }
     if ($s_probe_exc ne '' && $a_prid =~ /$s_probe_exc/i)
      {
        $msg_excluded++;
        goto bypass;
      }

     if ($s_message_inc ne '')
      { 
         if ($a_message =~ /$s_message_inc/i ) 
           {
             $domatch=1;
           }
         else
           {
             $msg_excluded++;
             if ($debug eq 'y') { print "Excluded $msg_excluded in message: $a_message\n"; }
             goto bypass;
           }
      }
     if ($s_hostname_inc ne '')
      {
        if ($a_hostname =~ /$s_hostname_inc/i ) 
           {
            $domatch=1;
           }
         else
           {
             $msg_excluded++;
             if ($debug eq 'y') { print "Excluded $msg_excluded in hostname: $a_hostname\n"; }
             goto bypass;
           }
      }
     if ($s_robot_inc ne '')
      {
        if ($a_robot =~ /$s_robot_inc/i ) 
           {
             $domatch=1;
           }
         else
           {
             $msg_excluded++;
             if ($debug eq 'y') { print "Excluded $msg_excluded in robot: $a_robot\n"; }
             goto bypass;
           }
      }
     if ($s_probe_inc ne '')
      {
         if ($a_prid =~ /$s_probe_inc/i )
           {
             $domatch=1;
           }
         else
           {
             $msg_excluded++;
             if ($debug eq 'y') { print "Excluded $msg_excluded in probe: $a_prid\n"; }
             goto bypass;
           }
      }

# - end regex filters

# --- did we find a match?
     if ($domatch eq '1')
      {
        &do_match();
        $msg_selected++;
      }  
     else
      {  
#        $msg_excluded++;
      }   
# --- in case no filters are defined, print all
     if ($s_message_inc eq '' && $s_message_exc eq '' && $s_hostname_inc eq '' && $s_hostname_exc eq '' && $s_robot_inc eq '' && $s_robot_exc eq '' && $s_probe_inc eq '' && $s_probe_exc eq '' && $domatch ne '1')
      {
        &do_match();
        $msg_selected++;
      } 

bypass:
 } 

# --- disconnect ---
$dbh->disconnect();

# --- fill up the page
while ($teller < 45)
 {
  &report_emptyline;
  $teller = $teller + 1;
 }

# --- footers HTML
&report_end;

# --- close HTML
close (OUTFILE1);

print "\n";
print "Created report: $outfil.html \n";
print "(messages read: $sqlcount included: $msg_selected excluded: $msg_excluded)\n";
exit $msg_selected;
}

sub do_match
{
# - print HTML alarm line
  &report_detail;
#  print "$sqlcount: $a_time_origin $a_time_arrival $a_robot $a_subsys $a_prid $a_severity $a_message\n";
  $printcount++;
# - repeat title every xx lines
  $totcol++;
  if ($totcol > 30)
   {
    &report_header2();
    $totcol=0;
   } 
}

sub report_header1
 {
  print OUTFILE1 "<html>\n";
  print OUTFILE1 "<meta http-equiv=\"Content-Language\" content=\"en-us\">\n";
  print OUTFILE1 "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=windows-1252\">\n";
   print OUTFILE1 "<meta http-equiv=\"REFRESH\" CONTENT=\"$reportseconds\" content=\"no-cache\">\n"; 
  print OUTFILE1 "<title>Nimsoft Open Alarms</title>\n";
  print OUTFILE1 "</head>\n";
  print OUTFILE1 "<body>\n";
#  This section is used a header to indicate the type of report and when it was generated
  print OUTFILE1 "<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" style=\"border-collapse: collapse\" bordercolor=\"#111111\" width=\"100%\" id=\"AutoNumber1\">\n";
# Put references to other reports
  print OUTFILE1 "<tr>\n";
  print OUTFILE1 "<td width=\"100%\" bgcolor=\"#009AD6\" colspan=\"$colspan\" align=\"left\" height=\"30\"><b>\n";
  print OUTFILE1 "<font color=\"#FFFFFF\" face=\"MS Sans Serif\" size=\"2\">&nbsp;Nimsoft Active Alarms on $dag $dagnum $maand ($maandnum) $jaar $intim </font>\n";
  print OUTFILE1 "</b></td>\n";
  print OUTFILE1 "</tr>\n";
 }

sub report_emptyline
 {
  if ($tel eq "0")
   { 
    print OUTFILE1 "<tr>\n";
    print OUTFILE1 "<td><font face=\"Tahoma\" size=\"2\" color=\"#FFFFFF\">-</font></td>\n";
    print OUTFILE1 "<td><font face=\"Tahoma\" size=\"2\" color=\"#FFFFFF\">-</font></td>\n";
    print OUTFILE1 "<td><font face=\"Tahoma\" size=\"2\" color=\"#FFFFFF\">-</font></td>\n";
    print OUTFILE1 "<td><font face=\"Tahoma\" size=\"2\" color=\"#FFFFFF\">-</font></td>\n";
    print OUTFILE1 "<td><font face=\"Tahoma\" size=\"2\" color=\"#FFFFFF\">-</font></td>\n";
    print OUTFILE1 "<td><font face=\"Tahoma\" size=\"2\" color=\"#FFFFFF\">-</font></td>\n";
    print OUTFILE1 "<td><font face=\"Tahoma\" size=\"2\" color=\"#FFFFFF\">-</font></td>\n";
    print OUTFILE1 "<td><font face=\"Tahoma\" size=\"2\" color=\"#FFFFFF\">-</font></td>\n";
    print OUTFILE1 "</tr>\n";
    $tel = 1;
   }
  else
   {
    print OUTFILE1 "<tr>\n";
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n";
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#D2FFFF\">-</font></td></pre>\n";
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n";
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#D2FFFF\">-</font></td></pre>\n";
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n";
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#D2FFFF\">-</font></td></pre>\n";
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n";
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#D2FFFF\">-</font></td></pre>\n";
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n";
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#D2FFFF\">-</font></td></pre>\n";
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n";
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#D2FFFF\">-</font></td></pre>\n";
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n";
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#D2FFFF\">-</font></td></pre>\n";
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n";
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#D2FFFF\">-</font></td></pre>\n";
    print OUTFILE1 "</tr>\n";
    $tel = 0;
   }
 }

sub report_end
 {
  &report_fieldex;
  print OUTFILE1 "</table>\n";
  print OUTFILE1 "</body>\n";
  print OUTFILE1 "</html>\n";
  print OUTFILE1 "<p align=\"center\"><font face=\"Arial\" size=\"-2\">Copyright $jaar (generated by $pgm)<br>\n";
  print OUTFILE1 "<a href=\"http://www.ca.com\">CA</a></font></p>\n";
 }

sub report_header2
 {
# print month title
     print OUTFILE1 "<tr>\n";
     print OUTFILE1 "<td bgcolor=\"#6BC3CE\"><font face=\"Arial\" size=\"2\"><b>&nbsp;Count</b></font></td>\n";
     print OUTFILE1 "<td bgcolor=\"#6BC3CE\"><font face=\"Arial\" size=\"2\"><b>&nbsp;Created</b></font></td>\n";
     print OUTFILE1 "<td bgcolor=\"#6BC3CE\"><font face=\"Arial\" size=\"2\"><b>&nbsp;Robot</b></font></td>\n";
     print OUTFILE1 "<td bgcolor=\"#6BC3CE\"><font face=\"Arial\" size=\"2\"><b>&nbsp;Subsys</b></font></td>\n";
     print OUTFILE1 "<td bgcolor=\"#6BC3CE\"><font face=\"Arial\" size=\"2\"><b>&nbsp;Probe </b></font></td>\n";
     print OUTFILE1 "<td bgcolor=\"#6BC3CE\"><font face=\"Arial\" size=\"2\"><b>&nbsp;Severity</b></font></td>\n";
     print OUTFILE1 "<td bgcolor=\"#6BC3CE\"><font face=\"Arial\" size=\"2\"><b>&nbsp;S</b></font></td>\n";
     print OUTFILE1 "<td bgcolor=\"#6BC3CE\"><font face=\"Arial\" size=\"2\"><b>&nbsp;Message</b></font></td>\n";
     print OUTFILE1 "</tr>\n";
 }

# $a_time_origin $a_time_arrival $a_robot $a_subsys $a_prid $a_severity $a_message
sub report_detail
 {
   if ($tel eq "0")
    { 
    print OUTFILE1 "<tr>\n";
    print OUTFILE1 "<td><pre><font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$printcount</font></td></pre>\n";
    print OUTFILE1 "<td><pre><font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$a_time_origin</font></td></pre>\n";
    print OUTFILE1 "<td><pre><font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$a_robot</font></td></pre>\n";
    print OUTFILE1 "<td><pre><font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$a_subsys</font></td></pre>\n";
    print OUTFILE1 "<td><pre><font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$a_prid</font></td></pre>\n";
    print OUTFILE1 "<td><pre><font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$a_severity</font></td></pre>\n";
    print OUTFILE1 "<td><pre>\n";
    if ($a_level eq '1' || $a_level eq 'S')
    {
       print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#00FF00\">&nbsp;&#9632;</font>\n";
    }
    else
    { 
      if ($a_level eq '5' || $a_level eq '4')
       {
         print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#FF0000\">&nbsp;&#9632;</font>\n";
       } 
      else
       {
         if ($a_level eq ' ')
          {
           print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#FFFFFF\">&nbsp;&#9632;</font>\n";
          } 
         else
          {
           print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#FFFF00\">&nbsp;&#9632;</font>\n";
          }
       } 
    } 
    print OUTFILE1 "</td></pre>\n";
    print OUTFILE1 "<td><pre><font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$a_message</font></td></pre>\n";
    print OUTFILE1 "</tr>\n";
    $tel = 1;
    }
   else
    {
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n"; 
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$printcount</font></td></pre>\n"; 
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n"; 
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$a_time_origin</font></td></pre>\n"; 
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n"; 
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$a_robot</font></td></pre>\n"; 
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n"; 
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$a_subsys</font></td></pre>\n"; 
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n"; 
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$a_prid</font></td></pre>\n"; 
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n"; 
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$a_severity</font></td></pre>\n"; 
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n";
    if ($a_level eq '1' || $a_level eq 'S')
    {
       print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#00FF00\">&nbsp;&#9632;</font>\n";
    }
    else
    { 
      if ($a_level eq '5' || $a_level eq '4')
       {
         print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#FF0000\">&nbsp;&#9632;</font>\n";
       } 
      else
       {
        if ($a_level eq ' ')
         {
          print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#D2FFFF\">&nbsp;&#9632;</font>\n";
         } 
        else
         {
           print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#FFFF00\">&nbsp;&#9632;</font>\n";
         }
       }   
     }
    print OUTFILE1 "<td bgcolor=\"#D2FFFF\"><pre>\n"; 
    print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">&nbsp;$a_message</font></td></pre>\n"; 
    print OUTFILE1 "</tr>\n";
    $tel = 0;
    }
    $teller++;
 }

sub calcdate
 {
  $timeval = time();
  @timelist = gmtime ($timeval);
  if (@timelist[6] eq '0') { $dag = "Sunday" }
  if (@timelist[6] eq '1') { $dag = "Monday" }
  if (@timelist[6] eq '2') { $dag = "Tuesday" }
  if (@timelist[6] eq '3') { $dag = "Wednesday" }
  if (@timelist[6] eq '4') { $dag = "Thursday" }
  if (@timelist[6] eq '5') { $dag = "Friday" }
  if (@timelist[6] eq '6') { $dag = "Saturday" }
  if (@timelist[4] eq '0') { $maand = "January" }
  if (@timelist[4] eq '1') { $maand = "February" }
  if (@timelist[4] eq '2') { $maand = "March" }
  if (@timelist[4] eq '3') { $maand = "April" }
  if (@timelist[4] eq '4') { $maand = "May" }
  if (@timelist[4] eq '5') { $maand = "June" }
  if (@timelist[4] eq '6') { $maand = "July" }
  if (@timelist[4] eq '7') { $maand = "Augustus" }
  if (@timelist[4] eq '8') { $maand = "September" }
  if (@timelist[4] eq '9') { $maand = "October" }
  if (@timelist[4] eq '10') { $maand = "November" }
  if (@timelist[4] eq '11') { $maand = "December" }
  $maandnum = @timelist[4] +1;
  $dagnum = @timelist[3] ;
  $jaar = @timelist[5] + 1900;
#
# get time 
#
  $intim1 = time();
  $intim2 = localtime($intim1);
  @intime = split(/ +/ , $intim2);
  $intim = $intime[3]; 


  print ("Today its $dag $dagnum $maand ($maandnum) $jaar $intim \n");
 }

sub report_fieldex
{
# Field explanation
print OUTFILE1 "</table>\n";
print OUTFILE1 "<table>\n";
print OUTFILE1 "<table border=\"0\" cellpadding=\"0\" cellspacing=\"0\" style=\"border-collapse: collapse\" bordercolor=\"#111111\" width=\"100%\" id=\"AutoNumber1\">\n";
print OUTFILE1 "<tr>\n";
print OUTFILE1 "<td width=\"100%\" bgcolor=\"#009AD6\" colspan=\"$colspan\" align=\"left\" height=\"30\"><b>\n";
print OUTFILE1 "<pre><font color=\"#D2FFFF\" face=\"MS Sans Serif\" size=\"2\">&nbsp;Field explanation";
print OUTFILE1 "</b></td></pre>\n";
print OUTFILE1 "</tr>\n";

# --- start with blue empty line
$tel=1;
&report_emptyline;
$tel=0;
&report_emptyline; 

print OUTFILE1 "<tr><td bgcolor=\"#D2FFFF\"><pre>\n"; 
print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">Count:</font></td></pre>\n";
print OUTFILE1 "<td bgcolor=\"#D2FFFF\" colspan=\"$colspan\" align=\"left\"><pre>\n"; 
print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">Simple counter for the generated alarms</font></td></pre></tr>\n"; 
  
print OUTFILE1 "<tr><td width=\"10%\"><pre><font face=\"Tahoma\" size=\"2\" color=\"#000080\">Created: </font></td></pre>\n";
print OUTFILE1 "<td width=\"90%\"><pre><font face=\"Tahoma\" size=\"2\" color=\"#000080\">Data\\Time the alarms was generated</font></td></pre></tr>\n";

print OUTFILE1 "<tr><td bgcolor=\"#D2FFFF\"><pre>\n"; 
print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">Robot:</font></td></pre>\n";
print OUTFILE1 "<td bgcolor=\"#D2FFFF\" colspan=\"$colspan\" align=\"left\"><pre>\n"; 
print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">Machine name where the probe is installed</font></td></pre></tr>\n"; 
  
print OUTFILE1 "<tr><td width=\"10%\"><pre><font face=\"Tahoma\" size=\"2\" color=\"#000080\">Subsys: </font></td></pre>\n";
print OUTFILE1 "<td width=\"90%\"><pre><font face=\"Tahoma\" size=\"2\" color=\"#000080\">Subsys name</font></td></pre></tr>\n";

print OUTFILE1 "<tr><td bgcolor=\"#D2FFFF\"><pre>\n"; 
print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">Probe:</font></td></pre>\n";
print OUTFILE1 "<td bgcolor=\"#D2FFFF\" colspan=\"$colspan\" align=\"left\"><pre>\n"; 
print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">Probe name\\id</font></td></pre></tr>\n"; 
  
print OUTFILE1 "<tr><td width=\"10%\"><pre><font face=\"Tahoma\" size=\"2\" color=\"#000080\">Severity: </font></td></pre>\n";
print OUTFILE1 "<td width=\"90%\"><pre><font face=\"Tahoma\" size=\"2\" color=\"#000080\">Severity of the generated alarm</font></td></pre></tr>\n";

print OUTFILE1 "<tr><td bgcolor=\"#D2FFFF\"><pre>\n"; 
print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">Message:</font></td></pre>\n";
print OUTFILE1 "<td bgcolor=\"#D2FFFF\" colspan=\"$colspan\" align=\"left\"><pre>\n"; 
print OUTFILE1 "<font face=\"Tahoma\" size=\"2\" color=\"#000080\">Message text</font></td></pre></tr>\n"; 

# --- start with white empty line
$tel=0;
&report_emptyline;
$tel=1;
&report_emptyline;   
}


sub getparams
{
  usage() unless @ARGV gt 0;
  $argCount=$#ARGV + 1;

  for ($i=0 ; $i < $argCount ; $i++) 
  {
	if ($ARGV[$i] =~ /^-\?/)
	{ 
		usage();
	} 
   
	if ($ARGV[$i] =~ /^-d/ )   
	{ 
		$outdir =  substr($ARGV[$i],2);
        }
	if ($ARGV[$i] =~ /^-f/ )   
	{ 
		$outfile =  substr($ARGV[$i],2);
        }
	if ($ARGV[$i] =~ /^-s/ )   
	{ 
		$reportseconds =  substr($ARGV[$i],2);
        }
	if ($ARGV[$i] =~ /^-s/ )   
	{ 
		$sqluser =  substr($ARGV[$i],2);
        }
	if ($ARGV[$i] =~ /^-p/ )   
	{ 
		$sqlpass =  substr($ARGV[$i],2);
        }
	if ($ARGV[$i] =~ /^-r/ )   
	{ 
		$sqlserver =  substr($ARGV[$i],2);
        }
	if ($ARGV[$i] =~ /^-i/ )   
	{ 
		$dbdir =  substr($ARGV[$i],2);
        }


	if ($ARGV[$i] =~ /^-mi/ )   
	{ 
		$s_message_inc =  substr($ARGV[$i],3);
        }
	if ($ARGV[$i] =~ /^-me/ )   
	{ 
		$s_message_exc =  substr($ARGV[$i],3);
        }
	if ($ARGV[$i] =~ /^-hi/ )   
	{ 
		$s_hostname_inc =  substr($ARGV[$i],3);
        }
	if ($ARGV[$i] =~ /^-he/ )   
	{ 
		$s_hostname_exc =  substr($ARGV[$i],3);
        }
	if ($ARGV[$i] =~ /^-ti/ )   
	{ 
		$s_robot_inc =  substr($ARGV[$i],3);
        }
	if ($ARGV[$i] =~ /^-te/ )   
	{ 
		$s_robot_exc =  substr($ARGV[$i],3);
        }
	if ($ARGV[$i] =~ /^-oi/ )   
	{ 
		$s_probe_inc =  substr($ARGV[$i],3);
        }
	if ($ARGV[$i] =~ /^-oe/ )   
	{ 
		$s_probe_exc =  substr($ARGV[$i],3);
        }

  }

# --- get credentials and settings from common file (nimsoft_generic.dat)
($Server_With_Rest_Interface, $RestServicePort, $UIM_username, $UIM_password,$UIM_Domain,$UIM_Hub,$UIM_Robot,$sql_server,$sql_user,$sql_password,$sql_db,$sql_type) = nimsoft_generic::getRestData();

# -- de-crypt (need $encoded)
$decoded = decode_base64($UIM_password);
$UIM_password = RC4($crkey, $decoded);

$decoded = decode_base64($sql_password);
$sql_password = RC4($crkey, $decoded);

# --- if not used in parameters, use defaults from generic
if ($sqluser eq '') { $sqluser=$sql_user; }
if ($sqlpass eq '') { $sqlpass=$sql_password; }
if ($sqlserver eq '') { $sqlserver=$sql_server; }
if ($database eq '') { $database=$sql_db; }


# --- set defaults
  if ($sqlopt eq '1' || $sqlopt eq '')
   {
      $sqltype="ms";
   }
  if ($sqlopt eq '2')
   {
      $sqltype="my";
   }
  if ($sql_type eq 'mssql')
   {
      $sqltype="ms";
   } 
  if ($sql_type eq 'mysql')
   {
      $sqltype="my";
   } 
  if ($sql_user eq 'trusted')
      {
         $trusted=yes;
      }

  if ($outdir eq '')
   {
     $outdir = "c:\\temp";
   }

  if ($dbdir eq '')
   {
     $dbdir = "C:\\Progra~2\\Nimsoft\\probes\\service\\nas";
   }

  if ($outfile eq '')
   {
     $outfile = "report\_nimsoft\_open\_alarms";
   }
  if ($reportseconds eq '')
   {
     $reportloop=N;
   }
  else
   {
     $reportloop=Y;
   }

  if ($sqlserver eq '')
   {
     $sqlserver=$hostn;
     print "We will connect the the mysql DB on server: $sqlserver\n";
    }

  if ($s_message_inc ne '')
   {
     if ($s_message_inc eq 'all')
      {
        $s_message_inc="";
      }
     else
      {   
        print "Using message include filter: $s_message_inc\n";
      }
   } 
  if ($s_message_exc ne '')
   {
     print "Using message exclude filter: $s_message_exc\n";
   } 
  if ($s_hostname_inc ne '')
   {
     print "Using hostname include filter: $s_hostname_inc\n";
   } 
  if ($s_hostname_exc ne '')
   {
     print "Using hostname exclude filter: $s_hostname_exc\n";
   } 
  if ($s_robot_inc ne '')
   {
     print "Using robot include filter: $s_robot_inc\n";
   } 
  if ($s_robot_exc ne '')
   {
     print "Using robot exclude filter: $s_robot_exc\n";
   } 

  if ($s_probe_inc ne '')
   {
     print "Using probe include filter: $s_probe_inc\n";
   } 
  if ($s_probe_exc ne '')
   {
     print "Using probe exclude filter: $s_probe_exc\n";
   } 

# --- create dir + name
$outfil = "$outdir\\$outfile";

}

sub usage
 {
   print "      \n";
   print "nimsoft_open_alarms\n";
   print "      \n";
   print "  Input parameters:\n";
   print "  -d: (opt) output directory (default: c:\\temp)\n";
   print "  -f: (opt) output file (default: report_nimsoft_open_alarms)\n";

   print "      \n";
   print "  Search Criteria: (regex)\n";
   print "  -mi: message text include (use -mi\"all\" to select all msg)\n";
   print "  -me: message text exclude\n";
   print "  -hi: hostname include\n";
   print "  -he: hostname exclude\n";
   print "  -ti: roboT include\n";
   print "  -te: roboT exclude\n";
   print "  -oi: prObe include\n";
   print "  -oe: prObe exclude\n";
   print "      \n";
   exit 0;
}

